@@ -2,11 +2,13 @@ package Aspect::Pointcut::Highest;
 
 use strict;
 use warnings;
-use Carp             ();
-use Params::Util     ();
-use Aspect::Pointcut ();
+use Carp                               ();
+use Scalar::Util                       ();
+use Params::Util                       ();
+use Aspect::Pointcut                   ();
+use Aspect::Pointcut::Highest::Cleanup ();
 
-our $VERSION = '0.97_02';
+our $VERSION = '0.97_03';
 our @ISA     = 'Aspect::Pointcut';
 
 
@@ -44,19 +46,13 @@ sub match_curry {
 sub compile_runtime {
 	my $depth = 0;
 	return sub {
-		my $cleanup  = sub { $depth-- };
-		bless $cleanup, 'Aspect::Pointcut::Highest::Cleanup';
-		$_->{highest} = $cleanup;
+		$_->{highest} = Aspect::Pointcut::Highest::Cleanup->new(
+			sub { $depth-- }
+		);
 		return ! $depth++;
 	};
 }
 
-package Aspect::Pointcut::Highest::Cleanup;
-
-sub DESTROY {
-	$_[0]->();
-}
-
 1;
 
 __END__
